@@ -2,9 +2,10 @@ package Parse::HTTP::UserAgent::Base::Parsers;
 use strict;
 use vars qw( $VERSION );
 use Parse::HTTP::UserAgent::Constants qw(:all);
-use Carp qw(croak);
+use constant ERROR_MAXTHON_VERSION => "Unable to extract Maxthon version from Maxthon UA-string";
+use constant ERROR_MAXTHON_MSIE    => "Unable to extract MSIE from Maxthon UA-string";
 
-$VERSION = '0.13';
+$VERSION = '0.14';
 
 sub _extract_dotnet {
     my $self = shift;
@@ -31,7 +32,7 @@ sub _fix_opera {
     return if ! $self->[UA_EXTRAS];
     my @buf;
     foreach my $e ( @{ $self->[UA_EXTRAS] } ) {
-        if ( $e =~ m{ \A (Opera \s+ Mini) / (.+?) \z }xms ) {
+        if ( $e =~ RE_OPERA_MINI ) {
             $self->[UA_ORIGINAL_NAME]    = $1;
             $self->[UA_ORIGINAL_VERSION] = $2;
             next;
@@ -60,34 +61,41 @@ sub _fix_generic {
 sub _parse_maxthon {
     my($self, $moz, $thing, $extra, @others) = @_;
     my @omap = grep { $_ } map { split m{;\s+?}xms, $_ } @others;
-    my($maxthon, $msie);
-
-    my @buf;
+    my($maxthon, $msie, @buf);
     foreach my $e ( @omap, @{$thing} ) { # $extra -> junk
         if ( index(uc $e, 'MAXTHON') != -1 ) { $maxthon = $e; next; }
         if ( index(uc $e, 'MSIE'   ) != -1 ) { $msie    = $e; next; }
         push @buf, $e;
     }
 
-    # make this a warning after development?
-    croak "Unable to extract Maxthon version from Maxthon UA-string" if ! $maxthon;
-    croak "Unable to extract MSIE from Maxthon UA-string" if ! $msie;
+    if ( ! $maxthon ) {
+        warn ERROR_MAXTHON_VERSION;
+        $self->[UA_UNKNOWN] = 1;
+        return;
+    }
 
-    $self->_parse_msie($moz, [ undef, @buf ], undef, split /\s+/, $msie);
+    if ( ! $msie ) {
+        warn ERROR_MAXTHON_MSIE;
+        $self->[UA_UNKNOWN] = 1;
+        return;
+    }
 
-    my(undef, $mv) = split m{ \s+ }xms, $maxthon;
-    $self->[UA_ORIGINAL_VERSION] = $mv || (
-        $maxthon ? '1.0' : croak "Unable to extract Maxthon version?"
-    );
-    $self->[UA_ORIGINAL_NAME] = 'Maxthon';
+    $self->_parse_msie($moz, [ undef, @buf ], undef, split RE_WHITESPACE, $msie);
+
+    my(undef, $mv) = split RE_WHITESPACE, $maxthon;
+    my $v = $mv      ? $mv
+          : $maxthon ? '1.0'
+          :            do { warn ERROR_MAXTHON_VERSION; 0 }
+          ;
+
+    $self->[UA_ORIGINAL_VERSION] = $v;
+    $self->[UA_ORIGINAL_NAME]    = 'Maxthon';
     return;
 }
 
 sub _parse_msie {
     my($self, $moz, $thing, $extra, $name, $version) = @_;
     my $junk = shift @{ $thing }; # already used
-    # "Microsoft Internet Explorer";
-
     my($extras,$dotnet) = $self->_extract_dotnet( $thing, $extra );
 
     if ( @{$extras} == 2 && index( $extras->[1], 'Lunascape' ) != -1 ) {
@@ -104,7 +112,7 @@ sub _parse_msie {
 
     my @buf;
     foreach my $e ( @{ $extras } ) {
-        if ( $e =~ m{ \A (Trident) / (.+?) \z }xmsi ) {
+        if ( $e =~ RE_TRIDENT ) {
             $self->[UA_TOOLKIT] = [ $1, $2 ];
             next;
         }
@@ -124,10 +132,10 @@ sub _parse_firefox {
 sub _parse_safari {
     my $self = shift;
     my($moz, $thing, $extra, @others) = @_;
-    $self->[UA_NAME]        = 'Safari';
-    my($version, @junk)     = split m{\s+}xms, pop @others;
+    my($version, @junk)     = split RE_WHITESPACE, pop @others;
+    my $ep = $version && index( lc($version), 'epiphany' ) != -1;
     (undef, $version)       = split RE_SLASH, $version;
-    $self->[UA_NAME]        = 'Safari';
+    $self->[UA_NAME]        = $ep ? 'Epiphany' : 'Safari';
     $self->[UA_VERSION_RAW] = $version;
     $self->[UA_TOOLKIT]     = [ split RE_SLASH, $extra->[0] ];
     $self->[UA_LANG]        = pop @{ $thing };
@@ -248,6 +256,10 @@ sub _parse_gecko {
                 $self->[UA_LANG] = $e;
                 next;
             }
+            if ( $e =~ RE_EPIPHANY_GECKO ) {
+                $self->[UA_NAME]        = $before = $1;
+                $self->[UA_VERSION_RAW] = $2;
+            }
             push @buf, $e;
         }
 
@@ -270,8 +282,8 @@ sub _parse_gecko {
 sub _parse_netscape {
     my $self            = shift;
     my($moz, $thing)    = @_;
-    my($mozx, $junk)    = split m{ \s+ }xms, $moz;
-    my(undef, $version) = split RE_SLASH, $mozx;
+    my($mozx, $junk)    = split RE_WHITESPACE, $moz;
+    my(undef, $version) = split RE_SLASH     , $mozx;
     my @buf;
     foreach my $e ( @{ $thing } ) {
         if ( my $s = $self->_is_strength($e) ) {
@@ -396,8 +408,8 @@ Parse::HTTP::UserAgent::Base::Parsers - Base class
 
 =head1 DESCRIPTION
 
-This document describes version C<0.13> of C<Parse::HTTP::UserAgent::Base::Parsers>
-released on C<28 August 2009>.
+This document describes version C<0.14> of C<Parse::HTTP::UserAgent::Base::Parsers>
+released on C<29 August 2009>.
 
 Internal module.
 
